@@ -9,7 +9,7 @@ test_that('classify', {
     d <- matrix(rnorm(nitems))
     dat <- simdata(a, d, 500, itemtype = 'dich')
     colnames(dat) <- itemnames
-    mod <- mirt(dat, 1, verbose = FALSE, TOL = .5)
+    mod <- mirt(dat, 1, verbose = FALSE)
     
     set.seed(1)
     Theta <- matrix(c(-1.5, 0, 1.5))
@@ -19,7 +19,7 @@ test_that('classify', {
     out <- sapply(res, function(x) x$classification)
     expect_true(all(out == c("below cutoff", "no decision", "above cutoff")))
     out <- sapply(res, function(x) x$thetas)
-    expect_equal(out, c(-0.997271152, -0.005986742, 1.045035109), tolerance = 1e-4)
+    expect_equal(out, c(-0.91889242, -0.00231641, 1.29913938), tolerance = 1e-4)
     
     set.seed(1234)
     nitems <- 50
@@ -31,7 +31,7 @@ test_that('classify', {
     colnames(dat) <- itemnames
     mod2 <- mirt(dat, mirt.model('F1 = 1-25
                                  F2 = 26-50
-                                 COV = F1*F2'), verbose = FALSE, TOL = .5)
+                                 COV = F1*F2'), verbose = FALSE)
     Theta <- matrix(c(-1.5, 0, 1.5,-1.5,0,2), 3, 2)
     pats <- generate_pattern(mod2, Theta = Theta)
     res <- mirtCAT(mo=mod2, criteria = 'Drule', start_item = 'Drule', local_pattern = pats,
@@ -41,17 +41,15 @@ test_that('classify', {
                                            "no decision", "no decision", 
                                            "above cutoff", "above cutoff")))
     out <- sapply(res, function(x) x$thetas)
-    expect_equal(as.numeric(out), c(-1.5164219, -1.4566952, 0.1128962, 0.5229815,
-                                    1.0865988,  1.2154775), tolerance = 1e-2)
+    expect_equal(as.numeric(out), c(-1.048084,-1.948572,-0.04265088,0.5091915,1.016837,1.170242), tolerance = 1e-2)
     
     preCAT <- list(response_variance = TRUE, min_items = 1, max_items = 20, method = 'fixed')    
     res <- mirtCAT(mo=mod, criteria = 'KL', start_item = 'MI', local_pattern = pats,
                    design = list(classify=0, classify_CI=.95), preCAT=preCAT)
-    expect_equal(summary(res[[1]])$thetas_history[1:6,1], c(0,0,0,-0.4033607,-0.5572152,-0.8296894), tolerance = 1e-4)
-    expect_equal(summary(res[[2]])$thetas_history[1:6,1], c(0,0,0,0,0.8378148,0.6034093), tolerance = 1e-4)
-    expect_equal(summary(res[[3]])$thetas_history[6:8,1], c(0, 1.056420, 1.236754), tolerance = 1e-4)
+    expect_equal(summary(res[[1]])$thetas_history[1:6,1], c(0,0,0,-0.4076504,-0.5483628,-0.8057573), tolerance = 1e-4)
+    expect_equal(summary(res[[2]])$thetas_history[1:6,1], c(0,0,0,0.487194,0.3061727,0.1235797), tolerance = 1e-4)
     scored <- summary(res[[3]], sort=FALSE)$scored_responses
     out <- fscores(mod, response.pattern = scored)
-    expect_equal(as.numeric(out[,'F1']), 1.301461, tolerance = 1e-4)
+    expect_equal(as.numeric(out[,'F1']), 1.763056, tolerance = 1e-4)
     
 })
\ No newline at end of file
